"""Pylons environment configuration"""
import os

from jinja2 import ChoiceLoader, Environment, FileSystemLoader
import pylons
from pylons.configuration import PylonsConfig
from sqlalchemy import engine_from_config

from sloecode.bzr import BazaarRepositoryFactory
import sloecode.lib.app_globals as app_globals
import sloecode.lib.helpers
from sloecode.config.routing import make_map
from sloecode.model import init_model


def load_environment(global_conf, app_conf):
    """Configure the Pylons environment via the ``pylons.config``
    object
    """
    config = PylonsConfig()

    # Pylons paths
    root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    paths = dict(root=root,
                 controllers=os.path.join(root, 'controllers'),
                 static_files=os.path.join(root, 'public'),
                 templates=[os.path.join(root, 'templates')])

    # Initialize config with the basic options
    config.init_app(global_conf, app_conf, package='sloecode', paths=paths)

    config['routes.map'] = make_map(config)
    config['pylons.app_globals'] = app_globals.Globals(config)
    config['pylons.h'] = sloecode.lib.helpers

    # Setup cache object as early as possible
    pylons.cache._push_object(config['pylons.app_globals'].cache)

    # Create the Jinja2 Environment
    config['pylons.app_globals'].jinja2_env = Environment(
        extensions=['jinja2.ext.do'],
        loader=ChoiceLoader(
            [FileSystemLoader(path) for path in paths['templates']]))
    # Jinja2's unable to request c's attributes without strict_c
    config['pylons.strict_tmpl_context'] = True

    # Setup the SQLAlchemy database engine
    engine = engine_from_config(config, 'sqlalchemy.')
    init_model(engine)

    # CONFIGURATION OPTIONS HERE (note: all config options will override
    # any Pylons config options)
    config['bzr.factory'] = BazaarRepositoryFactory(
        app_conf['bzr_person_root'],
        app_conf['bzr_project_root'])

    return config
