"""Routes configuration

The more specific and detailed routes should be defined first so they
may take precedent over the more generic routes. For more information
refer to the routes manual at http://routes.groovie.org/docs/
"""
from routes import Mapper

def make_map(config):
    """Create, configure and return the routes Mapper"""
    map = Mapper(directory=config['pylons.paths']['controllers'],
                 always_scan=config['debug'])
    map.minimization = False
    map.explicit = False

    # The ErrorController route (handles 404/500 error pages); it should
    # likely stay at the top, ensuring it can always be resolved
    map.connect('/error/{action}', controller='error')
    map.connect('/error/{action}/{id}', controller='error')

    # CUSTOM ROUTES HERE
    

    # Map / to the index controller:
    map.connect('/', controller='index', action='front_page')
    # Map /p/foo
    map.connect('/p/{project_name}/{action}', controller='project')
    map.connect('/p/{project_name}', controller='project', action='index')
    
    # map '/me' to the portal page. This allows us to show the user portal
    # no matter who logs in:
    map.connect('/me', controller='person', action='me')
    # map /u/foo
    map.connect('/u/{person_name}/{action}', controller='person')
    map.connect('/u/{person_name}', controller='person', action='index')
    
    map.connect('/a/project/{action}', controller='admin/project')
    map.connect('/a/project/{action}/{id}', controller='admin/project')
    map.connect('/a/person/{action}', controller='admin/person')
    map.connect('/a/person/{action}/{id}', controller='admin/person')

    map.connect('/{controller}/{action}')
    map.connect('/{controller}/{action}/{id}')
    return map
