"""Controller for non-admin views on the person object.
"""
import logging
from pylons import request
from pylons.controllers.util import redirect
from repoze.what.plugins.pylonshq import ActionProtector
from repoze.what.predicates import Any
from routes import url_for

from sloecode.lib.base import BaseController
from sloecode.lib.predicates import has_site_role, owns_page
from sloecode.model.site_role import USER_ADMIN
from sloecode.model.person import Person


log = logging.getLogger(__name__)


class PersonController(BaseController):
    """PersonController renders pages for the person model.
    """
    
    @ActionProtector(Any(has_site_role(role=USER_ADMIN), owns_page()))
    def index(self, person_name):
        """Render the person details page.
        """
        ppl = Person.get(login=person_name)
        person = None
        if len(ppl):
            person = ppl[0]
            
        return self.render('/person-details.html', {'person' : person})
        
    # allow anonymous action, since all we do is redirect to a page with
    # checks:
    def me(self):
        """Redirect to the main user page.
        """
        user = request.environ['repoze.who.identity'].get('user')
        return redirect(url_for(controller='/person', action='index', 
                                person_name=user.login))
        
        