"""The base Controller API

Provides the BaseController class for subclassing.
"""

from pylons.controllers import WSGIController
from pylons.templating import render_jinja2 as render
from pylons import request

from sloecode.model.meta import Session


class BaseController(WSGIController):
    "Base class for all sloecode controllers."

    def __call__(self, environ, start_response):
        """Invoke the Controller"""
        # WSGIController.__call__ dispatches to the Controller method
        # the request is routed to. This routing information is
        # available in environ['pylons.routes_dict']
        try:
            return WSGIController.__call__(self, environ, start_response)
        finally:
            Session.remove()

    def template_context(self):
        '''Return a dictionary containing values to be made available to
        templates.
        '''

        # keys should all be strings, values can be whatever you want!
        return {'identity': request.environ.get('repoze.who.identity')}

    def render(self, path, additional_vars=None):
        '''Render tempalte path with template context.

        You may pass in additional variables to be sent to this template only.
        For variables that are required across all templates please override
        the template_context() method (making sure to call the base
        implementation!)
        '''

        global_vars = additional_vars or {}
        global_vars.update(self.template_context())
        return render(path, global_vars)
