"""Functions that perform various security checks. Used by security predicate
classes, and also from within template code.
"""

from pylons import request
from sloecode.model import Person, Membership, Project, ProjectRole
from sloecode.model.meta import Session


def has_site_role(role_name, user=None):
    """Determines whether the currently logged in user has the specified
    site-role.

    If passed, user must be a Person object.
    """
    try:
        if not user:
            e = request.environ
            user = e['repoze.who.identity'].get('user')

        if user:
            for role in user.site_roles:
                if role.role == role_name:
                    return True
        return False
    except KeyError:
        return False


def has_project_role(project, role_name, user=None):
    """Determines whether the currently logged in user has the specified role
    for a given project. The project can either be the project name (as a
    string or unicode string), a Project object, or the project id (int).
    """
    prj_obj = None
    if isinstance(project, Project):
        prj_obj = project
    elif isinstance(project, int):
        projects = Project.get(id=project)
        if len(projects):
            prj_obj = projects[0]
        else:
            # that ID does not exist. return false:
            return False
    elif isinstance(project, basestring):
        projects = Project.get(name=project)
        if len(projects):
            prj_obj = projects[0]
        else:
            # that name does not exist. return false:
            return False
    else:
        raise TypeError("project must be Project,str,unicode, or int type.")
    try:
        if not user:
            e = request.environ
            user = e['repoze.who.identity'].get('user')
        # long query:
        q = Session.query(Person).filter_by(id=user.id) \
            .join(Membership).filter_by(project=prj_obj) \
            .join(ProjectRole).filter_by(role=role_name)
        # any results?
        return q.count() > 0
    except KeyError:
        return False