"""DB Model for storing authentication keys. Probably SSH keys.
"""

from sqlalchemy import Column
from sqlalchemy.types import Integer, Text
from sqlalchemy.schema import ForeignKey

from sloecode.model.meta import Base, QueryMixin


class AuthKey(Base, QueryMixin):
    "A model that holds authentication keys for a user."
    __tablename__ = "person_keys"

    id = Column(Integer, primary_key=True)
    person_id = Column(ForeignKey('person.id'))
    # key_type, so we can store whatever kind of key we want. Maybe this
    # should be an enum?
    key_type = Column(Integer)
    # key text. Not sure if the type here should be Text or Binary. Certainly
    # for SSh keys we can store them as text, but other algorithms use binary
    # keys.... but then we could always encode them before storing...
    key_data = Column(Text)


