"""SQLAlchemy Metadata and Session object"""
from sqlalchemy import MetaData
from sqlalchemy.orm import scoped_session, sessionmaker
from sqlalchemy.ext.declarative import declarative_base

__all__ = ['Session', 'metadata']

# SQLAlchemy session manager. Updated by model.init_model()
Session = scoped_session(sessionmaker())

# Global metadata. If you have multiple databases with overlapping table
# names, you'll need a metadata for each database
metadata = MetaData()

# Store global engine. We need this so we can reset the database for unit
# tests
engine = None

# Create Base object, allowing SQLAlchemy declarative shorthand. This is the
# recommended approach in pylons:
Base = declarative_base()

# A simple mix-in class that contains several methods that wrap sqlalchemy
# methods, making common operations a bit easier:
class QueryMixin(object):
    """A mix-in class that provides easier query methods than the default
    SQLAlchemy ones.
    """
    
    @classmethod
    def get(cls, **kwargs):
        """Wrap the SQLAlchemy crap up in this function. Return a list of Person
        objects that match the args passed in.
        """
        return Session.query(cls).filter_by(**kwargs).all()

