"""Project model.
"""

import formencode
from sqlalchemy import Column
from sqlalchemy.types import Integer, String, Text

from sloecode.model.meta import Base, QueryMixin


class Project(Base, QueryMixin):
    """Project model.

    Projects have project names and descriptions. Will probably contain more
    in the future.
    """
    __tablename__ = "project"

    id = Column(Integer, primary_key=True)
    name = Column(String(200), unique=True)
    description = Column(Text())


class UniqueProject(formencode.FancyValidator):
    "A simple formencode validator that checks Project names are unique."

    def _to_python(self, value, state):
        """Validate form-data.
        """
        if len(Project.get(name=value.strip)) > 0:
            raise formencode.Invalid(
                'A project with that name already exists.', value, state)
        return value


class ProjectSchema(formencode.Schema):
    """A formencode schema for the Project object."""

    allow_extra_fields = True
    filter_extra_fields = True

    name = formencode.All(UniqueProject(not_empty=True),
        formencode.validators.PlainText(not_empty=True))
    description = formencode.validators.String(not_empty=True)
