"""Site role DB model.
"""

from sqlalchemy import Column
from sqlalchemy.schema import ForeignKey
from sqlalchemy.types import Integer, Enum

from sloecode.model.meta import Base, QueryMixin

# labels so templates don't need to spell things properly:
USER_ADMIN = 'User Admin'
PROJECT_ADMIN = 'Project Admin'
SITE_ROLES = (USER_ADMIN, PROJECT_ADMIN)

class SiteRole(Base, QueryMixin):
    """A model that stores different site-wide roles.
    """

    __tablename__ = "site_role"

    id = Column(Integer, primary_key=True)
    person_id = Column(ForeignKey('person.id'))
    # Note: if we want to support PostgreSQL we need to specify name and
    # schema kwargs for all Enums.
    # TODO - need to think of better, more descriptive names here:
    role = Column(Enum(USER_ADMIN, PROJECT_ADMIN))


