#!/usr/bin/env python

from sqlalchemy.exc import IntegrityError
from unittest import TestCase

from sloecode.model.meta import Session, Base, engine
from sloecode.model import Person, AuthKey

class TestAuthKeys(TestCase):
    def setUp(self):
        # create all DB tables:
        Base.metadata.create_all(engine)

    def tearDown(self):
        # remove all DB tables.
        Base.metadata.drop_all(engine)
        # remove session - avoids a memory leak, apparently.
        Session.remove()

    def test_keys(self):
        "Basic AuthKey model insert & Retrieve test."

        thomi = Person(login='thomir', name='Thomi Richards')
        kd = '''ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQCapSH+u1QBZjOkvGEUlVTv9\
lfM4rbiqGv/zR2GlfVGjgllM+cfR1R5DDOsOHlhdFxqgE+6Y3RZQBs0DEVMb1MMi1javUE67aWfuU\
gaCElxWMiKXnsCvJ4UkbizxMlQzmP54dL366QHQDfTK5k+e52IFa1mnWM7GkpbpnhvL3gafyGtINL\
mcxcNBCV/L8ivZjsJBhZOx8xUmAYHryfEC/c6YMqiD/FS9l4Qq3oUq220X8tmYT7ebyzhBBuzcBHn\
GyOFaPerIm7pNKYJEp/RC9o8kw4N+WRZGtAEBODTzeXLA0zgSZPM/ynBiWSQRZ2ajU3f01RDPz82/\
cBQjTWug6hv thomi@thomi-VirtualBox'''
        thomi.auth_keys.append(AuthKey(key_type=0, key_data=kd))

        Session.add(thomi)
        Session.commit()

        qi = Session.query(AuthKey)
        # should only have one key in the Authkeys table
        self.assertTrue(len(qi.all()) == 1)
        # thomi should only have one key:
        self.assertTrue(len(thomi.auth_keys) == 1)
