#!/usr/bin/env python

from unittest import TestCase

from sloecode.model.meta import Session, Base, engine
from sloecode.model.person import Person
from sloecode.model.project import Project
from sloecode.model.membership import Membership

class TestMembership(TestCase):
    def setUp(self):
        # create all DB tables:
        Base.metadata.create_all(engine)

    def tearDown(self):
        # remove all DB tables.
        Base.metadata.drop_all(engine)
        # remove session - avoids a memory leak, apparently.
        Session.remove()

    def test_simple_membership(self):
        "Simple insert & retrieve test for the many-to-many membership table."
        # make sure we can create a user, create a project, then add a user
        # to the project:
        thomi = Person(login='thomir', name='Thomi Richards', email='thomir@gmail.com')
        sloecode = Project(name='sloecode',
                        description='Awesome code-hosting project of awesomeness')
        Session.add(thomi)
        Session.add(sloecode)

        membership = Membership(person=thomi, project=sloecode)
        Session.add(membership)
        Session.commit()

        self.assertTrue(len(thomi.projects) == 1)
        self.assertTrue(thomi.projects[0].project.name == 'sloecode')
        self.assertTrue(len(sloecode.users) == 1)
        self.assertTrue(sloecode.users[0].person.name == 'Thomi Richards')

        # now add a second user to the project:
        tim = Person(login='thumper', name='Tim Penhey', email='tim@penhey.net')
        Session.add(Membership(person=tim, project=sloecode))
        Session.commit()

        self.assertTrue(len(tim.projects) == 1)
        self.assertTrue(len(sloecode.users) == 2)

        for user_membership in sloecode.users:
            self.assertTrue(user_membership.person == tim or user_membership.person == thomi)

        # now add another project, so Tim is a member of two projects at once:
        wikkid = Project(name='wikkid', description='bzr enabled wiki of coolness')
        Session.add(wikkid)
        Session.add(Membership(person=tim, project=wikkid))
        Session.commit()

        self.assertTrue(len(tim.projects) == 2)
        for user_membership in tim.projects:
            self.assertTrue(user_membership.project == sloecode or user_membership.project == wikkid)