#!/usr/bin/env python

from sqlalchemy.exc import IntegrityError
from unittest import TestCase

from sloecode.model.meta import Session, Base, engine
from sloecode.model.project import Project

class TestProject(TestCase):
    def setUp(self):
        # create all DB tables:
        Base.metadata.create_all(engine)

    def tearDown(self):
        # remove all DB tables.
        Base.metadata.drop_all(engine)
        # remove session - avoids a memory leak, apparently.
        Session.remove()

    def test_create(self):
        "can we create a project?"

        p1 = Project(name='Test project 1')
        self.failIf(p1 is None)

    def test_unique(self):
        "Test to make sure the project name is unique."

        p1 = Project(name='myAwesomeProject')
        Session.add(p1)
        Session.commit()

        p2 = Project(name='myAwesomeProject')
        Session.add(p2)
        self.failUnlessRaises(IntegrityError, Session.commit)



